@@ -79,7 +79,7 @@ methodType = Optional[Literal["nearest", "pad", "ffill", "backfill", "bfill"]]
 
 
 logger = logging.getLogger("openghg.analyse")
-logger.setLevel(logging.DEBUG)  # Have to set level for logger as well as handler
+logger.setLevel(logging.INFO)  # Have to set level for logger as well as handler
 
 
 class ModelScenario:
@@ -88,6 +88,9 @@ class ModelScenario:
     operations to be performed combining these inputs.
     """
 
+    def __bool__(self) -> bool:
+        return bool(self.obs) or bool(self.footprint) or bool(self.fluxes) or bool(self.bc)
+
     def __init__(
         self,
         site: Optional[str] = None,
@@ -171,8 +174,8 @@ class ModelScenario:
             site = obs_metadata["site"]
             species = obs_metadata["species"]
             inlet = obs_metadata["inlet"]
-            print("Updating any inputs based on observation data")
-            print(f"site: {site}, species: {species}, inlet: {inlet}")
+            logger.info("Updating any inputs based on observation data")
+            logger.info(f"site: {site}, species: {species}, inlet: {inlet}")
 
         # Add footprint data (directly or through keywords)
         self.add_footprint(
@@ -242,6 +245,7 @@ class ModelScenario:
         if isinstance(keywords, dict):
             keywords = [keywords]
 
+        data = None
         num_checks = len(keywords)
         for i, keyword_set in enumerate(keywords):
             try:
@@ -249,21 +253,19 @@ class ModelScenario:
             except (SearchError, AttributeError):
                 num = i + 1
                 if num == num_checks:
-                    print(f"Unable to add {data_type} data based on keywords supplied.")
-                    print(" Inputs - \n")
+                    logger.warning(f"Unable to add {data_type} data based on keywords supplied.")
+                    logger.warning(" Inputs -")
                     for key, value in keyword_set.items():
-                        print(f" {key}: {value}\n")
+                        logger.info(f" {key}: {value}")
                     if search_fn is not None:
                         data_search = search_fn(**keyword_set)  # type:ignore
-                        print("---- Search results ---")
-                        print(f"Number of results returned: {len(data_search)}")
-                        print(data_search)
-                        # TODO: If we can determine how many results are returned from search
-                        # we can use this to give better information about why no data has
-                        # been found for these inputs.
+                        logger.info("---- Search results ---")
+                        logger.info(f"Number of results returned: {len(data_search)}")
+                        logger.info(data_search.results)
+                    print("\n")
                 data = None
             else:
-                print(f"Adding {data_type} to model scenario")
+                logger.info(f"Adding {data_type} to model scenario")
                 break
 
         return data
@@ -337,7 +339,7 @@ class ModelScenario:
             if inlet is None and self.obs is not None:
                 inlet = self.obs.metadata["inlet"]
             elif inlet is None and height is not None:
-                inlet = height                        
+                inlet = height
                 inlet = clean_string(inlet)
                 inlet = format_inlet(inlet)
             else:
@@ -438,14 +440,17 @@ class ModelScenario:
 
         # TODO: Make this so flux.anthro can be called etc. - link in some way
         if self.fluxes is not None:
-            if flux is not None:
+            if flux:
                 self.fluxes.update(flux)
         else:
-            self.fluxes = flux
+            # Flux can be None or empty dict.
+            if flux:
+                self.fluxes = flux
 
         if self.fluxes is not None:
             if not hasattr(self, "species"):
                 flux_values = list(self.fluxes.values())
+
                 flux_1 = flux_values[0]
                 self.species = flux_1.metadata["species"]
 
@@ -508,9 +513,9 @@ class ModelScenario:
             if value is None:
                 missing.append(attr)
 
-                print(f"Must have {attr} data linked to this ModelScenario to run this function")
-                print("Include this by using the add function, with appropriate inputs:")
-                print("  ModelScenario.add_{attr}(...)")
+                logger.error(f"Must have {attr} data linked to this ModelScenario to run this function")
+                logger.error("Include this by using the add function, with appropriate inputs:")
+                logger.error("  ModelScenario.add_{attr}(...)")
 
         if missing:
             raise ValueError(f"Missing necessary {' and '.join(missing)} data.")
@@ -519,9 +524,10 @@ class ModelScenario:
         """
         Find the platform for a site, if present.
 
-        This will access the "acrg_site_info.json" file to find this information.
+        This will access the "site_info.json" file from openghg_defs dependency to 
+        find this information.
         """
-        from openghg.util import load_json
+        from openghg.util import get_site_info
 
         try:
             site = self.site
@@ -529,9 +535,9 @@ class ModelScenario:
         except AttributeError:
             return None
         else:
-            site_info = load_json(filename="acrg_site_info.json")
+            site_data = get_site_info()
             try:
-                site_details = site_info[site_upper]
+                site_details = site_data[site_upper]
             except KeyError:
                 return None
             else:
@@ -597,7 +603,7 @@ class ModelScenario:
             obs_data_period_s = float(obs_attributes["sampling_period"])
         elif "sampling_period_estimate" in obs_attributes:
             estimate = obs_attributes["sampling_period_estimate"]
-            print(f"WARNING: Using estimated sampling period of {estimate}s for observational data")
+            logger.warning(f"Using estimated sampling period of {estimate}s for observational data")
             obs_data_period_s = float(estimate)
         else:
             infer_sampling_period = True
@@ -981,7 +987,7 @@ class ModelScenario:
 
         # Cache output from calculations
         if cache:
-            print("Caching calculated data")
+            logger.info("Caching calculated data")
             self.modelled_obs = modelled_obs
             # self.scenario[name] = modelled_obs
         else:
@@ -1178,7 +1184,7 @@ class ModelScenario:
 
         # Create times for matching to the flux
         full_dates = date_range(
-            date_start_back.values, date_end.values, freq=highest_resolution, closed="left"
+            date_start_back.values, date_end.values, freq=highest_resolution, inclusive="left"
         ).to_numpy()
 
         # Create low frequency flux data (monthly)
@@ -1226,7 +1232,7 @@ class ModelScenario:
         # Iterate through the time coord to get the total mf at each time step using the H back coord
         # at each release time we disaggregate the particles backwards over the previous 24hrs
         # The final value then contains the 29-day integrated residual footprints
-        print("Calculating modelled timeseries comparison:")
+        logger.info("Calculating modelled timeseries comparison:")
         iters = tqdm(time_array.values)
         for tt, time in enumerate(iters):
 
@@ -1429,10 +1435,18 @@ class ModelScenario:
         units_w = check_units(bc_data["vmr_w"], default=units_default)
 
         modelled_baseline = (
-            (scenario["particle_locations_n"] * bc_data["vmr_n"] * loss_n * units_n / output_units).sum(["height", "lon"])
-            + (scenario["particle_locations_e"] * bc_data["vmr_e"] * loss_e * units_e / output_units).sum(["height", "lat"])
-            + (scenario["particle_locations_s"] * bc_data["vmr_s"] * loss_s * units_s / output_units).sum(["height", "lon"])
-            + (scenario["particle_locations_w"] * bc_data["vmr_w"] * loss_w * units_w / output_units).sum(["height", "lat"])
+            (scenario["particle_locations_n"] * bc_data["vmr_n"] * loss_n * units_n / output_units).sum(
+                ["height", "lon"]
+            )
+            + (scenario["particle_locations_e"] * bc_data["vmr_e"] * loss_e * units_e / output_units).sum(
+                ["height", "lat"]
+            )
+            + (scenario["particle_locations_s"] * bc_data["vmr_s"] * loss_s * units_s / output_units).sum(
+                ["height", "lon"]
+            )
+            + (scenario["particle_locations_w"] * bc_data["vmr_w"] * loss_w * units_w / output_units).sum(
+                ["height", "lat"]
+            )
         )
 
         modelled_baseline.attrs["resample_to"] = resample_to
@@ -1441,7 +1455,7 @@ class ModelScenario:
 
         # Cache output from calculations
         if cache:
-            print("Caching calculated data")
+            logger.info("Caching calculated data")
             self.modelled_baseline = modelled_baseline
             # self.scenario[name] = modelled_obs
         else:
@@ -1513,7 +1527,7 @@ class ModelScenario:
                 name = modelled_baseline.name
                 combined_dataset = combined_dataset.assign({name: modelled_baseline})
             else:
-                print(
+                logger.warning(
                     "Unable to calculate baseline data. Add boundary conditions using ModelScenarion.add_bc(...) to do this."
                 )
 
@@ -1606,7 +1620,7 @@ class ModelScenario:
                 y_baseline = modelled_baseline.data
                 y_data = y_data + y_baseline
             else:
-                print("Unable to calculate baseline from boundary conditions")
+                logger.warning("Unable to calculate baseline from boundary conditions")
         elif baseline == "percentile":
             mf = obs.data["mf"]
             y_baseline = mf.quantile(1.0, dim="time").values
