@@ -5,6 +5,7 @@ from ._footprint_data import FootprintData
 from ._metdata import METData
 from ._obsdata import ObsData
 from ._obscolumn_data import ObsColumnData
-from ._ranksources import RankSources
+
+# from ._ranksources import RankSources
 from ._searchresults import SearchResults
 from ._datahandler import DataHandler
