@@ -3,13 +3,14 @@ from ._data_schema import DataSchema
 from ._emissions import Emissions
 from ._eulerian_model import EulerianModel
 from ._footprints import Footprints
-from ._infer_time import infer_date_range
+from ._infer_time import infer_date_range, update_zero_dim
 from ._metadata import ObjectStorage, datasource_lookup, load_metastore, data_handler_lookup
 from ._metstore import METStore
 from ._obsmobile import ObsMobile
 from ._obscolumn import ObsColumn
 from ._obssurface import ObsSurface
 from ._populate import add_noaa_obspack
-from ._rank import rank_sources
+
+# from ._rank import rank_sources
 from ._recombination import recombine_datasets, recombine_multisite
 from ._segment import assign_data
