@@ -5,7 +5,7 @@ from typing import DefaultDict, Dict, Optional, Sequence, Tuple, Union
 import numpy as np
 from openghg.store import DataSchema
 from openghg.store.base import BaseStore
-from openghg.types import multiPathType, pathType, resultsType
+from openghg.types import multiPathType, pathType, resultsType, optionalPathType
 from xarray import Dataset
 
 __all__ = ["ObsSurface"]
@@ -31,7 +31,11 @@ class ObsSurface(BaseStore):
 
     @staticmethod
     def read_data(
-        binary_data: bytes, metadata: Dict, file_metadata: Dict, precision_data: Optional[bytes] = None
+        binary_data: bytes,
+        metadata: Dict,
+        file_metadata: Dict,
+        precision_data: Optional[bytes] = None,
+        site_filepath: optionalPathType = None,
     ) -> Dict:
         """Reads binary data passed in by serverless function.
         The data dictionary should contain sub-dictionaries that contain
@@ -45,6 +49,8 @@ class ObsSurface(BaseStore):
             metadata: Metadata
             file_metadata: File metadata such as original filename
             precision_data: GCWERKS precision data
+            site_filepath: Alternative site info file (see openghg/supplementary_data repository for format).
+                Otherwise will use the data stored within openghg_defs/data/site_info JSON file by default.
         Returns:
             dict: Dictionary of result
         """
@@ -91,7 +97,9 @@ class ObsSurface(BaseStore):
                 precision_filepath = tmpdir_path.joinpath("precision_data.C")
                 precision_filepath.write_bytes(precision_data)
                 # Create the expected GCWERKS tuple
-                result = ObsSurface.read_file(filepath=(filepath, precision_filepath), **meta_kwargs)
+                result = ObsSurface.read_file(
+                    filepath=(filepath, precision_filepath), site_filepath=site_filepath, **meta_kwargs
+                )
 
         return result
 
@@ -109,6 +117,7 @@ class ObsSurface(BaseStore):
         measurement_type: str = "insitu",
         overwrite: bool = False,
         verify_site_code: bool = True,
+        site_filepath: optionalPathType = None,
     ) -> Dict:
         """Process files and store in the object store. This function
             utilises the process functions of the other classes in this submodule
@@ -129,6 +138,8 @@ class ObsSurface(BaseStore):
             measurement_type: Type of measurement e.g. insitu, flask
             overwrite: Overwrite previously uploaded data
             verify_site_code: Verify the site code
+            site_filepath: Alternative site info file (see openghg/supplementary_data repository for format).
+                Otherwise will use the data stored within openghg_defs/data/site_info JSON file by default.
         Returns:
             dict: Dictionary of Datasource UUIDs
 
@@ -153,16 +164,24 @@ class ObsSurface(BaseStore):
             raise ValueError(f"Unknown data type {source_format} selected.")
 
         # Test that the passed values are valid
-        # Check validity of site, instrument, inlet etc in acrg_site_info.json
+        # Check validity of site, instrument, inlet etc in 'site_info.json'
         # Clean the strings
-        site = verify_site(site=site) if verify_site_code else clean_string(site)
+        if verify_site_code:
+            verified_site = verify_site(site=site)
+            if verified_site is None:
+                raise ValueError("Unable to validate site")
+            else:
+                site = verified_site
+        else:
+            site = clean_string(site)
+
         network = clean_string(network)
         instrument = clean_string(instrument)
         # sampling_period = clean_string(sampling_period)
 
         # Check if alias `height` is included instead of `inlet`
         if inlet is None and height is not None:
-            inlet = height        
+            inlet = height
 
         # Try to ensure inlet is 'NUM''UNIT' e.g. "10m"
         inlet = clean_string(inlet)
@@ -225,6 +244,7 @@ class ObsSurface(BaseStore):
                         instrument=instrument,
                         sampling_period=sampling_period_seconds,
                         measurement_type=measurement_type,
+                        site_filepath=site_filepath,
                     )
                 else:
                     data = parser_fn(
@@ -236,6 +256,7 @@ class ObsSurface(BaseStore):
                         sampling_period=sampling_period_seconds,
                         measurement_type=measurement_type,
                         calibration_scale=calibration_scale,
+                        site_filepath=site_filepath,
                     )
 
                 # Current workflow: if any species fails, whole filepath fails
@@ -314,7 +335,7 @@ class ObsSurface(BaseStore):
                 progress_bar.update(1)
 
                 logger.info(f"Completed processing: {data_filepath.name}.")
-                logger.info(f"\tUUIDs: {datasource_uuids}")
+                # logger.info(f"\tUUIDs: {datasource_uuids}")
 
         # Ensure we explicitly close the metadata store
         # as we're using the cached storage method
