@@ -18,5 +18,16 @@ from ._errors import (
     MutexTimeoutError,
     RequestBucketError,
     SearchError,
+    AttrMismatchError,
+    construct_xesmf_import_error,
+)
+from ._types import (
+    multiPathType,
+    pathType,
+    optionalPathType,
+    resultsType,
+    ArrayLike,
+    ArrayLikeMatch,
+    XrDataLike,
+    XrDataLikeMatch,
 )
-from ._types import multiPathType, pathType, resultsType
